-------------------------------------------------------------------------------
-- Package Calendar_Utilities (specification)                                --
-- (C) Copyright 2001 ADALOG                                                 --
-- Author: J-P. Rosen                                                        --
--                                                                           --
-- Rights to use, distribute or modify this package in any way is hereby     --
-- granted, provided this header is kept unchanged in all versions and the   --
-- associated documentation file is distributed unchanged. Additionnal       --
-- headers or documentation may be added.                                    --
-- All modifications must be properly marked as not originating from Adalog. --
-- If you make a valuable addition, please keep us informed by sending a     --
-- message to rosen@adalog.fr                                                --
--                                                                           --
-- ADALOG is providing training, consultancy and expertise in Ada and        --
-- related software engineering techniques. For more info about our services:--
-- ADALOG                   Tel: +33 1 41 24 31 40                           --
-- 19-21 rue du 8 mai 1945  Fax: +33 1 41 24 07 36                           --
-- 94110 ARCUEIL            E-m: info@adalog.fr                              --
-- FRANCE                   URL: http://www.adalog.fr                        --
--                                                                           --
-- This package is distributed in the hope that it will be useful, but WITH- --
-- OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY  --
-- or FITNESS FOR A PARTICULAR PURPOSE.                                      --
-------------------------------------------------------------------------------

with Calendar;
use Calendar;
package Calendar_Utilities is
   Max_Image_Length : constant := 40;

   -- Syntax of format strings:
   -- %Y : Year number (4 digits!)
   -- %M : Month number
   -- %D : Day number
   -- %h : Hours
   -- %m : minutes
   -- %s : seconds
   -- %c : hundredth of second (cents :-)
   -- %<char> : <char> unchanged. Useful for %%
   -- Any other character is copied verbatim on output, and
   -- must be matched exactly on input.
   -- A misformed input string to Value raises Time_Error.
   -- Value is somewhat tolerant: if the input string is to short, defaults
   -- are taken for the missing fields (taken from the current date for the
   -- date, and 0:0:0.0 for the time).
   -- Extra spaces are allowed in front of numeric values.
   -- In any case, it is guaranteed that a string produced by Image with a
   -- format can be parsed by Value with the same format.
   Compact  : constant String := "%Y%M%D%h%m%s%c";
   European : constant String := "%D/%M/%Y %h:%m:%s";
   British  : constant String := "%M/%D/%Y %h:%m:%s";
   ISO      : constant String := "%Y/%M/%D %h:%m:%s.%c";

  function Image (Item : Time;   Format : String) return String;
  function Value (Item : String; Format : String) return Time;

  function Min (Left, Right : Time) return Time;
  function Max (Left, Right : Time) return Time;
end Calendar_Utilities;
